
#ifndef VTKPVPYTHONCATALYST_EXPORT_H
#define VTKPVPYTHONCATALYST_EXPORT_H

#ifdef VTKPVPYTHONCATALYST_STATIC_DEFINE
#  define VTKPVPYTHONCATALYST_EXPORT
#  define VTKPVPYTHONCATALYST_NO_EXPORT
#else
#  ifndef VTKPVPYTHONCATALYST_EXPORT
#    ifdef PythonCatalyst_EXPORTS
        /* We are building this library */
#      define VTKPVPYTHONCATALYST_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVPYTHONCATALYST_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVPYTHONCATALYST_NO_EXPORT
#    define VTKPVPYTHONCATALYST_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVPYTHONCATALYST_DEPRECATED
#  define VTKPVPYTHONCATALYST_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVPYTHONCATALYST_DEPRECATED_EXPORT
#  define VTKPVPYTHONCATALYST_DEPRECATED_EXPORT VTKPVPYTHONCATALYST_EXPORT VTKPVPYTHONCATALYST_DEPRECATED
#endif

#ifndef VTKPVPYTHONCATALYST_DEPRECATED_NO_EXPORT
#  define VTKPVPYTHONCATALYST_DEPRECATED_NO_EXPORT VTKPVPYTHONCATALYST_NO_EXPORT VTKPVPYTHONCATALYST_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVPYTHONCATALYST_NO_DEPRECATED
#    define VTKPVPYTHONCATALYST_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVPythonCatalystModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVPYTHONCATALYST_EXPORT_H */
